@@ -20,8 +20,6 @@
 __author__ = 'Nathan Woodrow'
 __date__ = 'November 2018'
 __copyright__ = '(C) 2018, Nathan Woodrow'
-# This will get replaced with a git SHA1 when you do a git archive
-__revision__ = '0c5774c0685d4b6f3e92a086234455708d1cd427'
 
 from collections import OrderedDict
 from functools import partial
@@ -56,7 +54,12 @@ from qgis.core import (QgsProcessingParameterDefinition,
                        QgsProcessingParameterRasterLayer,
                        QgsProcessingParameterVectorLayer,
                        QgsProcessingParameterMeshLayer,
+                       QgsProcessingParameterColor,
+                       QgsProcessingParameterScale,
+                       QgsProcessingParameterLayout,
+                       QgsProcessingParameterLayoutItem,
                        QgsProcessingOutputString,
+                       QgsProcessingOutputBoolean,
                        QgsProcessingOutputFile,
                        QgsProcessingOutputFolder,
                        QgsProcessingOutputHtml,
@@ -66,7 +69,8 @@ from qgis.core import (QgsProcessingParameterDefinition,
                        QgsProcessingOutputNumber,
                        QgsProcessingOutputRasterLayer,
                        QgsProcessingOutputVectorLayer,
-                       QgsMessageLog)
+                       QgsMessageLog,
+                       QgsApplication)
 
 
 def _log(*args, **kw):
@@ -131,7 +135,7 @@ class AlgWrapper(QgsProcessingAlgorithm):
             raise NotImplementedError()
 
     # Wrapper logic
-    def define(self, name, label, group, group_label, help=None, icon=None):
+    def define(self, name, label, group, group_label, help=None, icon=QgsApplication.iconPath("processingScript.svg")):
         self._name = name
         self._display = label
         self._group = group_label
@@ -318,6 +322,10 @@ class ProcessingAlgFactory():
     POINT = "POINT",
     RANGE = "RANGE",
     AUTH_CFG = "AUTH_CFG"
+    SCALE = "SCALE"
+    COLOR = "COLOR"
+    LAYOUT = "LAYOUT"
+    LAYOUT_ITEM = "LAYOUT_ITEM"
 
     def __init__(self):
         self._current = None
@@ -380,6 +388,7 @@ class ProcessingAlgFactory():
             alg.MULTILAYER:  QgsProcessingOutputMultipleLayers
             alg.RASTER_LAYER: QgsProcessingOutputRasterLayer
             alg.VECTOR_LAYER: QgsProcessingOutputVectorLayer
+            alg.BOOL: QgsProcessingOutputBoolean
 
         :param type: The type of the input. This should be a type define on `alg` like alg.STRING, alg.DISTANCE
         :keyword label: The label of the output. Will convert into `description` arg.
@@ -445,7 +454,10 @@ class ProcessingAlgFactory():
             alg.VECTOR_LAYER: QgsProcessingParameterVectorLayer
             alg.AUTH_CFG: QgsProcessingParameterAuthConfig
             alg.MESH_LAYER: QgsProcessingParameterMeshLayer
-
+            alg.SCALE: QgsProcessingParameterScale
+            alg.LAYOUT: QgsProcessingParameterLayout
+            alg.LAYOUT_ITEM: QgsProcessingParameterLayoutItem
+            alg.COLOR: QgsProcessingParameterColor
 
         :param type: The type of the input. This should be a type define on `alg` like alg.STRING, alg.DISTANCE
         :keyword label: The label of the output. Translates into `description` arg.
@@ -493,6 +505,10 @@ input_type_mapping = {
     ProcessingAlgFactory.VECTOR_LAYER: QgsProcessingParameterVectorLayer,
     ProcessingAlgFactory.AUTH_CFG: QgsProcessingParameterAuthConfig,
     ProcessingAlgFactory.MESH_LAYER: QgsProcessingParameterMeshLayer,
+    ProcessingAlgFactory.SCALE: QgsProcessingParameterScale,
+    ProcessingAlgFactory.LAYOUT: QgsProcessingParameterLayout,
+    ProcessingAlgFactory.LAYOUT_ITEM: QgsProcessingParameterLayoutItem,
+    ProcessingAlgFactory.COLOR: QgsProcessingParameterColor,
 }
 
 output_type_mapping = {
@@ -511,4 +527,5 @@ output_type_mapping = {
     ProcessingAlgFactory.MULTILAYER: partial(_make_output, cls=QgsProcessingOutputMultipleLayers),
     ProcessingAlgFactory.RASTER_LAYER: partial(_make_output, cls=QgsProcessingOutputRasterLayer),
     ProcessingAlgFactory.VECTOR_LAYER: partial(_make_output, cls=QgsProcessingOutputVectorLayer),
+    ProcessingAlgFactory.BOOL: partial(_make_output, cls=QgsProcessingOutputBoolean),
 }
